NAME

Number::Phone::Formatter::MSISDN - formatter for MSISDN-formatted phone number

DESCRIPTION

A formatter to output the number in MSISDN format. https://en.wikipedia.org/wiki/MSISDN

METHOD

format

This is the only method. It takes an E.123 international format string and a Number::Phone object, and outputs the MSISDN-formatted number.

+1 212 334 0611 -> 12123340611

Note that this uses data derived from libphonenumber, and if your object is not derived from that it will first create a temporary object. This may involve a small unexpected performance hit.

AUTHOR, COPYRIGHT and LICENCE

Copyright 2026 Mario Paumann <mario.paumann@gmail.com>

This software is free-as-in-speech software, and may be used, distributed, and modified under the terms of either the GNU General Public Licence version 2 or the Artistic Licence. It's up to you which one you use. The full text of the licences can be found in the files GPL2.txt and ARTISTIC.txt, respectively.